@@ -1,6 +1,8 @@
 import os
 
 import pretty_errors
+
+
 # from .widgets import timer
 
 
@@ -49,7 +51,7 @@ class Cli:
         return kill(*ports, view)
 
     @staticmethod
-    def clone(url: str, repo_name=None, branch=None):
+    def clone(url: str, save_path=None, branch=None, proxy=False):
         kwargs = locals()
         from .cli import clone
         return clone(**kwargs)
